Struct
QmiIndicationWmsTransportNetworkRegistrationStatusOutput
since: 1.38
Description [src]
struct QmiIndicationWmsTransportNetworkRegistrationStatusOutput {
/* No available fields */
}
The QmiIndicationWmsTransportNetworkRegistrationStatusOutput structure contains private data and should only be accessed
using the provided API.
Available since: 1.38
Instance methods
qmi_indication_wms_transport_network_registration_status_output_get_registration_status
Get the ‘Registration Status’ field from self.
since: 1.0
qmi_indication_wms_transport_network_registration_status_output_ref
Atomically increments the reference count of self by one.
since: 1.38
qmi_indication_wms_transport_network_registration_status_output_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.38